==> apache-hyracks-0.3.8-source-release.zip: apache-hyracks-0.3.8/algebricks/algebricks-data/src/main/java/org/apache/hyracks/algebricks/data/IResultSerializerFactoryProvider.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.hyracks.algebricks.data;

import java.io.Serializable;

import org.apache.hyracks.api.dataflow.value.IResultSerializerFactory;

public interface IResultSerializerFactoryProvider extends Serializable {
    /**
     * Returns a result serializer factory
     *
     * @param fields
     *            - A position of the fields in the order it should be written in the output.
     * @param printerFactories
     *            - A printer factory array to print the tuple containing different fields.
     * @param writerFactory
     *            - A writer factory to write the serialized data to the print stream.
     * @param inputRecordDesc
     *            - The record descriptor describing the input frame to be serialized.
     * @return A new instance of result serialized appender.
     */
    public IResultSerializerFactory getAqlResultSerializerFactoryProvider(int[] fields,
            IPrinterFactory[] printerFactories, IAWriterFactory writerFactory);
}

==> apache-hyracks-0.3.8.1-source-release.zip: apache-hyracks-0.3.8.1/algebricks/algebricks-data/src/main/java/org/apache/hyracks/algebricks/data/IResultSerializerFactoryProvider.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.hyracks.algebricks.data;

import java.io.Serializable;

import org.apache.hyracks.api.dataflow.value.IResultSerializerFactory;

public interface IResultSerializerFactoryProvider extends Serializable {
    /**
     * Returns a result serializer factory
     *
     * @param fields
     *            - A position of the fields in the order it should be written in the output.
     * @param printerFactories
     *            - A printer factory array to print the tuple containing different fields.
     * @param writerFactory
     *            - A writer factory to write the serialized data to the print stream.
     * @return A new instance of result serialized appender.
     */
    public IResultSerializerFactory getResultSerializerFactoryProvider(int[] fields, IPrinterFactory[] printerFactories,
            IAWriterFactory writerFactory);
}
